======================
Django MongoDB Backend
======================

version 5.1.x for Django 5.1.x

.. rubric:: Everything you need to know about Django MongoDB Backend.

First steps
===========

**Getting started:**

- :doc:`Installation <intro/install>`
- :doc:`Configuring a project <intro/configure>`
- :doc:`howto/contrib-apps`
- :doc:`topics/known-issues`

Getting help
============

Having trouble? We’d like to help!

- Try the :doc:`faq` – it’s got answers to many common questions.

- Looking for specific information? Try the :ref:`genindex`, :ref:`modindex`,
  or the detailed :doc:`table of contents <contents>`.

- Didn't find an answer? You're welcome to ask questions or give feedback on
  the `MongoDB Community Forum <https://www.mongodb.com/community/forums/tag/python>`_.

- Report bugs and request features in our :ref:`issue tracker <issue-tracker>`.

Models
======

**Reference material:**

- :doc:`ref/models/fields`
- :doc:`ref/models/querysets`
- :doc:`ref/models/models`

**Topic guides:**

- :doc:`topics/embedded-models`

Forms
=====

- :doc:`ref/forms`

Core functionalities
====================

- :doc:`topics/cache`

Miscellaneous
=============

- :doc:`releases/index`
- :doc:`internals`
